/*****************************************************************************
 * devicemanager.c: Device Manager scanner core code
 *****************************************************************************
 * $Id: devicemanager_config_file.c,v 1.1 2007/05/13 16:14:15 aballier Exp $
 *****************************************************************************
 * Copyright (C) 2007 Alexis Ballier
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 *****************************************************************************/

#include "devicemanager.h"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#ifndef DEVMAN_STANDALONE
extern char user_dir[255];
#else
char user_dir[] = "/tmp";
#endif

extern int debug;

char config_file_location[300];

#define DEVMAN_INITIALIZE_CONFIG_FILE_LOCATION snprintf(config_file_location, sizeof(config_file_location), "%s/devman.conf", user_dir)



struct devman_conf_params* devman_config_params = NULL;


int devman_read_config_file(){
  	FILE *fp;
	char line[100];
	char value_left[100];
	char* value_right;
	int ousuisje;
	int i;
	DEVMAN_INITIALIZE_CONFIG_FILE_LOCATION;
	if(debug) printf("config file location : %s\n", config_file_location);

	devman_config_params = (struct devman_conf_params*)malloc(sizeof(struct devman_conf_params));

	devman_config_params->device_name = NULL;

  	fp = fopen (config_file_location, "r");

	if (NULL == fp){
		fprintf (stderr, "Can't open config file %s:", config_file_location);
		fprintf (stderr, "will use default parameters.\n");
		return DEVMAN_SUCCESS;
	}

  	while (NULL != fgets (line, 99, fp)){
      		if (line[0] == '\n' || line[0] == '#' || line[0] == '%')
			continue;
		
		sscanf(line, "%s = %n", value_left, &ousuisje);
		value_right = line+ousuisje;

		/* Remove the \n at the end */
		for(i=0; value_right[i];i++)
			if(value_right[i] == '\n') value_right[i] = 0;


		if(debug) fprintf(stderr, "values read from config file : \n\tvalue left : %s\n\tvalue right : %s\n", value_left, value_right);

		if(strcmp(value_left, "device_name") == 0)
			devman_config_params->device_name = strdup(value_right);

	}

	fclose(fp);

	return DEVMAN_SUCCESS;
}



int devman_write_config_file(){
	FILE* fp;

	DEVMAN_INITIALIZE_CONFIG_FILE_LOCATION;

	unlink(config_file_location);

	fp = fopen(config_file_location, "w");

	fprintf(fp, "#[Device manager config file]\n");

	if(devman_config_params->device_name != NULL)
		fprintf(fp, "device_name = %s\n", devman_config_params->device_name);


	fclose(fp);

	return DEVMAN_SUCCESS;
}
